aboutsummaryrefslogtreecommitdiffstats
path: root/news/nn/files/patch-ac
blob: 16e02be4e247c32c6dd1dd0f944eb7b6e86382a7 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
--- inst.sh.orig    Thu Dec  6 19:52:24 2001
+++ inst.sh Thu Dec  6 19:53:23 2001
@@ -1,8 +1,8 @@
 
 # (Large) prefix inserted above by Make
 
-# BSD systems keep chown in /etc
-PATH="$PATH:/etc"
+# BSD systems keep chown in /usr/sbin
+PATH="$PATH:/usr/sbin"
 
 case "$1" in
 mkdir)
@@ -83,8 +83,8 @@
 if [ -s ErrorCheck ]
 then
    cat ErrorCheck
-   echo "Hit return to continue"
-   read X
+#  echo "Hit return to continue"
+#  read X
 fi
 rm -f ErrorCheck